@@ -86,7 +86,6 @@
 #include "config.h"
 
 /* SYSTEM (UNIX) includes */
-#include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
 #include <string.h>
@@ -101,6 +100,8 @@
 #include <unistd.h>
 #endif
 
+#include <glib/gstdio.h>
+
 /* GIMP includes */
 #include "gtk/gtk.h"
 #include "gap-intl.h"
@@ -122,15 +123,16 @@
 #endif
 
 /* GAP includes */
+#include "gap_arr_dialog.h"
+#include "gap_image.h"
 #include "gap_layer_copy.h"
 #include "gap_lib.h"
-#include "gap_pdb_calls.h"
-#include "gap_arr_dialog.h"
 #include "gap_lock.h"
 #include "gap_navi_activtable.h"
+#include "gap_onion_base.h"
+#include "gap_pdb_calls.h"
 #include "gap_thumbnail.h"
 #include "gap_vin.h"
-#include "gap_onion_base.h"
 
 
 extern      int gap_debug; /* ==0  ... dont print debug infos */
@@ -143,7 +145,7 @@ gboolean            p_set_active_layer_by_pos(gint32 image_id
                          ,gint32 ref_layer_stackpos
                          );
 gboolean            p_set_active_layer_by_name(gint32 image_id
-                          ,gchar *ref_layer_name
+                          ,const gchar *ref_layer_name
                           ,gint32 ref_layer_stackpos
                           );
 static gchar *      p_get_active_layer_name(gint32 image_id
@@ -246,10 +248,11 @@ p_set_active_layer_by_pos(gint32 image_id
  * set active layer by picking the layer
  * whos name matches best with ref_layer_name.
  * ref_layer_stackpos is the 2nd criterium
+ * restriction: works only for utf8 compliant layernames.
  */
 gboolean
 p_set_active_layer_by_name(gint32 image_id
-                          ,gchar *ref_layer_name
+                          ,const gchar *ref_layer_name
                           ,gint32 ref_layer_stackpos
                           )
 {
@@ -263,8 +266,8 @@ p_set_active_layer_by_name(gint32 image_id
   gint        l_score;
   gint        l_case_bonus;
   gint        l_max_score;
-  gint        l_ref_len;
-  gint        l_len;
+  glong       l_ref_len;
+  glong       l_len;
   char       *l_layer_name;
 
   if(gap_debug)
@@ -280,7 +283,12 @@ p_set_active_layer_by_name(gint32 image_id
     return(p_set_active_layer_by_pos(image_id, ref_layer_stackpos));
   }
   
-  l_ref_len = strlen(ref_layer_name);
+  if(!g_utf8_validate(ref_layer_name, -1, NULL))
+  {
+    return(p_set_active_layer_by_pos(image_id, ref_layer_stackpos));
+  }
+  
+  l_ref_len = g_utf8_strlen(ref_layer_name, -1);
   l_layers_list = gimp_image_get_layers(image_id, &l_nlayers);
   if(l_layers_list)
   {
@@ -294,40 +302,58 @@ p_set_active_layer_by_name(gint32 image_id
       {
         gint ii;
 
-	/* check how many characters of the name are equal */
-        l_len = strlen(l_layer_name);
-        for(ii=0; ii < MIN(l_len, l_ref_len); ii++)
-	{
-	  if(g_ascii_toupper(l_layer_name[ii]) == g_ascii_toupper(ref_layer_name[ii]))
+        if(g_utf8_validate(l_layer_name, -1, NULL))
+        {
+	  const char *uni_ref_ptr;
+	  const char *uni_nam_ptr;
+
+          uni_ref_ptr = ref_layer_name;
+	  uni_nam_ptr = l_layer_name;
+
+	  /* check how many characters of the name are equal */
+          l_len = g_utf8_strlen(l_layer_name, -1);
+          for(ii=0; ii < MIN(l_len, l_ref_len); ii++)
 	  {
-	    /* best score for matching character */
-	    l_score += 8;
-	    if(l_layer_name[ii] == ref_layer_name[ii])
+	    gunichar refname_char;
+	    gunichar layername_char;
+	    
+	    refname_char = g_utf8_get_char(uni_ref_ptr);
+	    layername_char = g_utf8_get_char(uni_nam_ptr);
+
+	    if(g_unichar_toupper(layername_char) == g_unichar_toupper(refname_char))
 	    {
-	      if(ii==0)
+	      /* best score for matching character */
+	      l_score += 8;
+	      if(layername_char == refname_char)
 	      {
-	        /* prepare bonus for matching in case sensitivity */
-	        l_case_bonus = 4;
+		if(ii==0)
+		{
+	          /* prepare bonus for matching in case sensitivity */
+	          l_case_bonus = 4;
+		}
+	      }
+	      else
+	      {
+		/* lost the bonus for exact matching in case sensitivity */
+		l_case_bonus = 0;
 	      }
 	    }
 	    else
 	    {
-	      /* lost the bonus for exact matching in case sensitivity */
-	      l_case_bonus = 0;
+              break;
 	    }
+	    uni_ref_ptr = g_utf8_find_next_char(uni_ref_ptr, NULL);
+	    uni_nam_ptr = g_utf8_find_next_char(uni_nam_ptr, NULL);
 	  }
-	  else
+
+	  l_score += l_case_bonus;
+	  if(l_len == l_ref_len)
 	  {
-            break;
+	    /* extra score for equal length */
+	    l_score += 2;
 	  }
-	}
-	
-	l_score += l_case_bonus;
-	if(l_len == l_ref_len)
-	{
-	  /* extra score for equal length */
-	  l_score += 2;
-	}
+        }
+
 	g_free(l_layer_name);
       }
       
@@ -382,6 +408,8 @@ p_set_active_layer_by_name(gint32 image_id
 }  /* end p_set_active_layer_by_name */
 
 
+
+
 /* ---------------------------------
  * p_get_active_layer_name
  * ---------------------------------
@@ -654,7 +682,7 @@ gap_lib_file_exists(const char *fname)
   long         l_len;
 
   /* File Laenge ermitteln */
-  if (0 != stat(fname, &l_stat_buf))
+  if (0 != g_stat(fname, &l_stat_buf))
   {
     /* stat error (file does not exist) */
     return(0);
@@ -784,7 +812,7 @@ gap_lib_file_copy(char *fname, char *fname_copy)
   if(gap_debug) printf("gap_lib_file_copy src:%s dst:%s\n", fname, fname_copy);
 
   /* File Laenge ermitteln */
-  if (0 != stat(fname, &l_stat_buf))
+  if (0 != g_stat(fname, &l_stat_buf))
   {
     fprintf (stderr, "stat error on '%s'\n", fname);
     return -1;
@@ -800,7 +828,7 @@ gap_lib_file_copy(char *fname, char *fname_copy)
   }
 
   /* load File into Buffer */
-  l_fp = fopen(fname, "rb");		    /* open read */
+  l_fp = g_fopen(fname, "rb");		    /* open read */
   if(l_fp == NULL)
   {
     fprintf (stderr, "open(read) error on '%s'\n", fname);
@@ -810,7 +838,7 @@ gap_lib_file_copy(char *fname, char *fname_copy)
   fread(l_buffer, 1, (size_t)l_len, l_fp);
   fclose(l_fp);
 
-  l_fp = fopen(fname_copy, "wb");		    /* open write */
+  l_fp = g_fopen(fname_copy, "wb");		    /* open write */
   if(l_fp == NULL)
   {
     fprintf (stderr, "file_copy: open(write) error on '%s' \n", fname_copy);
@@ -843,7 +871,7 @@ gap_lib_delete_frame(GapAnimInfo *ainfo_ptr, long nr)
    if(l_fname == NULL) { return(1); }
 
    if(gap_debug) printf("\nDEBUG gap_lib_delete_frame: %s\n", l_fname);
-   l_rc = remove(l_fname);
+   l_rc = g_remove(l_fname);
 
    gap_thumb_file_delete_thumbnail(l_fname);
 
@@ -872,7 +900,7 @@ gap_lib_rename_frame(GapAnimInfo *ainfo_ptr, long from_nr, long to_nr)
 
 
    if(gap_debug) printf("\nDEBUG gap_lib_rename_frame: %s ..to.. %s\n", l_from_fname, l_to_fname);
-   l_rc = rename(l_from_fname, l_to_fname);
+   l_rc = g_rename(l_from_fname, l_to_fname);
 
    gap_thumb_file_rename_thumbnail(l_from_fname, l_to_fname);
 
@@ -1682,6 +1710,13 @@ gap_lib_get_frame_nr_from_name(char *fname)
   return(-1);
 }
 
+/* -------------------------------
+ * gap_lib_get_frame_nr
+ * -------------------------------
+ * return -1 if the specified image is
+ *           NOT a gimp-gap typical frame image (e.g. has no number part in its filename)
+ * return the number part in case of valid frame image.
+ */
 long
 gap_lib_get_frame_nr(gint32 image_id)
 {
@@ -1689,12 +1724,16 @@ gap_lib_get_frame_nr(gint32 image_id)
   long  number;
 
   number = -1;
-  fname = gimp_image_get_filename(image_id);
-  if(fname)
+  if (gap_image_is_alive(image_id))
   {
-     number = gap_lib_get_frame_nr_from_name(fname);
-     g_free(fname);
+    fname = gimp_image_get_filename(image_id);
+    if(fname)
+    {
+       number = gap_lib_get_frame_nr_from_name(fname);
+       g_free(fname);
+    }
   }
+
   return (number);
 }
 
@@ -1854,6 +1893,13 @@ p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_na
 
   gimp_get_data (l_key_save_as_mode, &l_save_as_mode);
 
+  if(gap_debug)
+  {
+    printf("DEBUG: p_decide_save_as l_save_as_mode: %d\n"
+          , l_save_as_mode
+          );
+  }
+
   if(l_save_as_mode == -1)
   {
     gchar *l_key_gimprc;
@@ -1872,14 +1918,20 @@ p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_na
     }
     l_key_gimprc = g_strdup_printf("video-save-flattened-%s", l_ext);
 
-    if(gap_debug) printf("GIMPRC KEY:%s:\n", l_key_gimprc);
+    if(gap_debug)
+    {
+      printf("GIMPRC KEY:%s:\n", l_key_gimprc);
+    }
 
     l_val_gimprc = gimp_gimprc_query(l_key_gimprc);
     l_ask = TRUE;
 
     if(l_val_gimprc)
     {
-      if(gap_debug) printf("GIMPRC VAL:%s:\n", l_val_gimprc);
+      if(gap_debug)
+      {
+        printf("GIMPRC VAL:%s:\n", l_val_gimprc);
+      }
 
       if(strcmp(l_val_gimprc, "yes") == 0)
       {
@@ -1896,7 +1948,10 @@ p_decide_save_as(gint32 image_id, const char *sav_name, const char *final_sav_na
     }
     else
     {
-      if(gap_debug) printf("GIMPRC VAL:<NULL>\n");
+      if(gap_debug)
+      {
+        printf("GIMPRC VAL:<NULL>\n");
+      }
     }
 
     if(l_ask)
@@ -1998,39 +2053,51 @@ gap_lib_gap_check_save_needed(gint32 image_id)
 /* ============================================================================
  * gap_lib_save_named_image / 2
  * ============================================================================
+ * this procedure is typically used to save frame images in other image formats than
+ * gimp native XCF format.
  */
 static gint32
 p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_mode, gboolean enable_thumbnailsave)
 {
-  GimpDrawable  *l_drawable;
+  gint32      l_drawable_id;
   gint        l_nlayers;
   gint32     *l_layers_list;
   gboolean    l_rc;
 
-  if(gap_debug) printf("DEBUG: before   p_lib_save_named_image2: '%s'\n", sav_name);
+  if(gap_debug)
+  {
+    printf("DEBUG: before   p_lib_save_named_image2: '%s'\n", sav_name);
+  }
 
   l_layers_list = gimp_image_get_layers(image_id, &l_nlayers);
   if(l_layers_list == NULL)
-     return -1;
-
-  l_drawable =  gimp_drawable_get(l_layers_list[l_nlayers -1]);  /* use the background layer */
-  if(l_drawable == NULL)
   {
-     fprintf(stderr, "ERROR: p_lib_save_named_image2 gimp_drawable_get failed '%s' nlayers=%d\n",
-                     sav_name, (int)l_nlayers);
-     g_free (l_layers_list);
+     printf("ERROR: gap_lib.c.p_lib_save_named_image2: failed to save '%s' because has no layers\n"
+         , sav_name
+         );
      return -1;
   }
 
+  l_drawable_id = l_layers_list[l_nlayers -1];  /* use the background layer */
+
   l_rc = gimp_file_save(run_mode,
                  image_id,
-		 l_drawable->drawable_id,
+		 l_drawable_id,
 		 sav_name,
 		 sav_name /* raw name ? */
 		 );
 
 
-  if(gap_debug) printf("DEBUG: after    p_lib_save_named_image2: '%s' nlayers=%d image=%d drw=%d run_mode=%d\n", sav_name, (int)l_nlayers, (int)image_id, (int)l_drawable->drawable_id, (int)run_mode);
+  if(gap_debug)
+  {
+    printf("DEBUG: after    p_lib_save_named_image2: '%s' nlayers=%d image=%d drawable_id=%d run_mode=%d\n"
+        , sav_name
+        , (int)l_nlayers
+        , (int)image_id
+        , (int)l_drawable_id
+        , (int)run_mode
+        );
+  }
 
   if(enable_thumbnailsave)
   {
@@ -2041,15 +2108,19 @@ p_lib_save_named_image2(gint32 image_id, const char *sav_name, GimpRunMode run_m
     g_free(l_sav_name);
   }
 
-  if(gap_debug) printf("DEBUG: after thumbmail save\n");
+  if(gap_debug)
+  {
+    printf("DEBUG: after thumbmail save\n");
+  }
 
   g_free (l_layers_list);
-  g_free (l_drawable);
-
 
   if (l_rc != TRUE)
   {
-    fprintf(stderr, "ERROR: p_lib_save_named_image2  gimp_file_save failed '%s'\n", sav_name);
+    printf("ERROR: p_lib_save_named_image2  gimp_file_save failed '%s'  rc:%d\n"
+        , sav_name
+        ,(int)l_rc
+        );
     return -1;
   }
   return image_id;
@@ -2093,7 +2164,13 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
 
   /* check extension to decide if savd file will be zipped */
   l_ext = gap_lib_alloc_extension(sav_name);
-  if(l_ext == NULL)  return -1;
+  if(l_ext == NULL)
+  {
+    printf("gap_lib_save_named_frame failed for file:%s  (because it has no extension)\n"
+      ,sav_name
+      );
+    return -1;
+  }
 
   if(0 == strcmp(l_ext, ".xcf"))
   {
@@ -2123,21 +2200,28 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
   g_free(l_ext);
 
 
-   if(gap_debug)
-   {
-     l_ext = (gchar *) g_getenv("GAP_NO_SAVE");
-     if(l_ext != NULL)
-     {
-       fprintf(stderr, "DEBUG: GAP_NO_SAVE is set: save is skipped: '%s'\n", l_tmpname);
-       g_free(l_tmpname);  /* free if it was a temporary name */
-       return 0;
-     }
-   }
+  if(gap_debug)
+  {
+    char *env_no_save;
+    env_no_save = (gchar *) g_getenv("GAP_NO_SAVE");
+    if(env_no_save != NULL)
+    {
+      printf("DEBUG: GAP_NO_SAVE is set: save is skipped: '%s'\n", l_tmpname);
+      g_free(l_tmpname);  /* free if it was a temporary name */
+      return 0;
+    }
+  }
 
-  if(gap_debug) printf("DEBUG: before   gap_lib_save_named_frame: '%s'\n", l_tmpname);
 
   if(l_xcf != 0)
   {
+    if(gap_debug)
+    {
+      printf("DEBUG: gap_lib_save_named_frame before gimp_xcf_save on file: '%s'\n"
+            , l_tmpname
+            );
+    }
+
     /* save current frame as xcf image
      * xcf_save does operate on the complete image,
      * the drawable is ignored. (we can supply a dummy value)
@@ -2150,7 +2234,10 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
 			         GIMP_PDB_STRING, l_tmpname,
 			         GIMP_PDB_STRING, l_tmpname, /* raw name ? */
 			         GIMP_PDB_END);
-    if(gap_debug) printf("DEBUG: after   xcf  gap_lib_save_named_frame: '%s'\n", l_tmpname);
+    if(gap_debug)
+    {
+      printf("DEBUG: after   xcf  gap_lib_save_named_frame: '%s'\n", l_tmpname);
+    }
 
     if (l_params[0].data.d_status == GIMP_PDB_SUCCESS)
     {
@@ -2160,6 +2247,13 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
   }
   else
   {
+     if(gap_debug)
+     {
+       printf("DEBUG: gap_lib_save_named_frame before save NON-XCF file: '%s'\n"
+             , l_tmpname
+             );
+     }
+
      /* let gimp try to save (and detect filetype by extension)
       * Note: the most imagefileformats do not support multilayer
       *       images, and extra channels
@@ -2169,11 +2263,19 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
       */
 
      l_rc = p_decide_save_as(image_id, l_tmpname, sav_name);
+
+     if(gap_debug)
+     {
+       printf("DEBUG: gap_lib_save_named_frame after save NON-XCF file: '%s'  rc:%d\n"
+             , l_tmpname
+             , (int)l_rc
+             );
+     }
   }
 
   if(l_rc < 0)
   {
-     remove(l_tmpname);
+     g_remove(l_tmpname);
      g_free(l_tmpname);  /* free temporary name */
      return l_rc;
   }
@@ -2181,22 +2283,28 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
   if(l_gzip == 0)
   {
      /* remove sav_name, then rename tmpname ==> sav_name */
-     remove(sav_name);
-     if (0 != rename(l_tmpname, sav_name))
+     g_remove(sav_name);
+     if (0 != g_rename(l_tmpname, sav_name))
      {
         /* if tempname is located on another filesystem (errno == EXDEV)
          * rename will not work.
          * so lets try a  copy ; remove sequence
          */
-         if(gap_debug) printf("DEBUG: gap_lib_save_named_frame: RENAME 2nd try\n");
+         if(gap_debug)
+         {
+           printf("DEBUG: gap_lib_save_named_frame: RENAME 2nd try\n");
+         }
+         
          if(0 == gap_lib_file_copy(l_tmpname, sav_name))
 	 {
-	    remove(l_tmpname);
+	    g_remove(l_tmpname);
 	 }
          else
          {
-            fprintf(stderr, "ERROR in gap_lib_save_named_frame: can't rename %s to %s\n",
-                            l_tmpname, sav_name);
+            printf("ERROR in gap_lib_save_named_frame: can't rename %s to %s\n"
+                  , l_tmpname
+                  , sav_name
+                  );
             return -1;
          }
      }
@@ -2209,12 +2317,22 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
        /* OK zip created compressed file named sav_name
         * now delete the uncompressed l_tempname
         */
-       remove(l_tmpname);
+       g_remove(l_tmpname);
     }
   }
 
+  if(gap_debug)
+  {
+    printf("DEBUG: gap_lib_save_named_frame: before gap_thumb_cond_gimp_file_save_thumbnail\n");
+  }
+
   gap_thumb_cond_gimp_file_save_thumbnail(image_id, sav_name);
 
+  if(gap_debug)
+  {
+    printf("DEBUG: gap_lib_save_named_frame: after gap_thumb_cond_gimp_file_save_thumbnail\n");
+  }
+
   g_free(l_tmpname);  /* free temporary name */
 
   return l_rc;
@@ -2234,6 +2352,12 @@ p_save_old_frame(GapAnimInfo *ainfo_ptr, GapVinVideoInfo *vin_ptr)
    */
   if(gap_lib_gap_check_save_needed(ainfo_ptr->image_id))
   {
+    if(gap_debug)
+    {
+       printf("p_save_old_frame Save required for file:%s\n"
+             , ainfo_ptr->old_filename
+             );
+    }
     /* check and perform automatic onionskinlayer remove */
     if(vin_ptr)
     {
@@ -2244,6 +2368,15 @@ p_save_old_frame(GapAnimInfo *ainfo_ptr, GapVinVideoInfo *vin_ptr)
     }
     return (gap_lib_save_named_frame(ainfo_ptr->image_id, ainfo_ptr->old_filename));
   }
+  else
+  {
+    if(gap_debug)
+    {
+       printf("p_save_old_frame No save needed for file:%s OK\n"
+             , ainfo_ptr->old_filename
+             );
+    }
+  }
   return 0;
 }	/* end p_save_old_frame */
 
@@ -2298,7 +2431,7 @@ gap_lib_load_image (char *lod_name)
 
   if(l_tmpname != lod_name)
   {
-    remove(l_tmpname);
+    g_remove(l_tmpname);
     g_free(l_tmpname);  /* free if it was a temporary name */
   }
 
@@ -2324,17 +2457,33 @@ gap_lib_load_named_frame (gint32 old_image_id, char *lod_name)
 
   l_new_image_id = gap_lib_load_image(lod_name);
 
-  if(gap_debug) printf("DEBUG: after    gap_lib_load_named_frame: '%s' old_id=%d  new_id=%d\n\n",
+  if(gap_debug)
+  {
+    printf("DEBUG: after    gap_lib_load_named_frame: '%s' old_id=%d  new_id=%d\n\n",
                                lod_name, (int)old_image_id, (int)l_new_image_id);
+  }
 
   if(l_new_image_id < 0)
+  {
       return -1;
-
+  }
+  
   if (gap_pdb_gimp_displays_reconnect(old_image_id, l_new_image_id))
   {
-      /* delete the old image */
-      gimp_image_delete(old_image_id);
-
+      /* deleteing the old image if it is still alive
+       * (maybe still required gimp-2.2.x prior to gimp-2.2.11
+       * gimp-2.2.11 still accepts the delete, but the old image becomes invalid after
+       * reconnecting the display.
+       * gimp-2.3.8 even complains and breaks gimp-gap if we attempt to delete
+       * the old image. (see #339840)
+       * GAP has no more chance for explicite delete the old image
+       * (hope that this is already done implicite by gimp_reconnect_displays ?)
+       */
+       
+      if(gap_image_is_alive(old_image_id))
+      {
+        gimp_image_delete(old_image_id);
+      }
 
       gimp_image_undo_disable(l_new_image_id);
 
@@ -2381,31 +2530,74 @@ gap_lib_replace_image(GapAnimInfo *ainfo_ptr)
   gint32    ref_active_layer;
   gint32    ref_layer_stackpos;
   gchar    *ref_layer_name;
+  int       save_rc;
 
   do_onionskin_crate  = FALSE;
 
+  if(gap_debug)
+  {
+    printf("gap_lib_replace_image START\n");
+  }
+
   ref_layer_name = p_get_active_layer_name(ainfo_ptr->image_id
                                           ,&ref_active_layer
                                           ,&ref_layer_stackpos
                                           );  
   
-  if(ainfo_ptr->new_filename != NULL) g_free(ainfo_ptr->new_filename);
+  if(ainfo_ptr->new_filename != NULL)
+  {
+    g_free(ainfo_ptr->new_filename);
+  }
   ainfo_ptr->new_filename = gap_lib_alloc_fname(ainfo_ptr->basename,
                                       ainfo_ptr->frame_nr,
                                       ainfo_ptr->extension);
   if(ainfo_ptr->new_filename == NULL)
+  {
+     if(gap_debug)
+     {
+       printf("gap_lib_replace_image (1) return because ainfo_ptr->new_filename == NULL\n");
+     }
      return -1;
-
+  }
+  
   if(0 == gap_lib_file_exists(ainfo_ptr->new_filename ))
+  {
+     if(gap_debug)
+     {
+       printf("gap_lib_replace_image (2) return because %s does not exist (or is empty)\n"
+             , ainfo_ptr->new_filename
+             );
+     }
      return -1;
+  }
+
+  if(gap_debug)
+  {
+     printf("gap_lib_replace_image (3) ainfo_ptr->new_filename:%s OK\n"
+           , ainfo_ptr->new_filename
+            );
+  }
 
   vin_ptr = gap_vin_get_all(ainfo_ptr->basename);
-  if(p_save_old_frame(ainfo_ptr, vin_ptr) < 0)
+  save_rc = p_save_old_frame(ainfo_ptr, vin_ptr);
+  if(gap_debug)
+  {
+    printf("gap_lib_replace_image (4) automatic save: save_rc:%d, old_filename:%s\n"
+           , (int)save_rc
+           , ainfo_ptr->old_filename
+            );
+  }
+
+  if(save_rc < 0)
   {
     if(vin_ptr)
     {
       g_free(vin_ptr);
     }
+    printf("gap_lib_replace_image (5) automatic save failed: save_rc:%d, old_filename:%s\n"
+           , (int)save_rc
+           , ainfo_ptr->old_filename
+            );
     return -1;
   }
 
@@ -2462,6 +2654,11 @@ gap_lib_replace_image(GapAnimInfo *ainfo_ptr)
     g_free(ref_layer_name);
   }
 
+  if(gap_debug)
+  {
+    printf("gap_lib_replace_image ENDED regular\n");
+  }
+
   return(image_id);
 }	/* end gap_lib_replace_image */
 
@@ -2570,7 +2767,7 @@ p_clear_or_count_video_paste(gint delete_flag)
              if(delete_flag)
              {
                 if(gap_debug) printf("gap_vid_edit_clear: remove file %s\n", l_filename);
-                remove(l_filename);
+                g_remove(l_filename);
 
                 /* also delete thumbnail */
                 gap_thumb_file_delete_thumbnail(l_filename);
@@ -2685,7 +2882,7 @@ p_custom_palette_file(char *filename, guchar *rgb, gint count)
 {
   FILE *l_fp;
 
-  l_fp= fopen(filename, "w");
+  l_fp= g_fopen(filename, "w");
   if (l_fp == NULL)
   {
     return -1;
@@ -3025,3 +3222,52 @@ gap_lib_sscan_flt_numbers(gchar   *buf
 
   return (l_cnt);
 }  /* end gap_lib_sscan_flt_numbers */
+
+
+/* --------------------------------
+ * gap_lib_check_tooltips
+ * --------------------------------
+ * check and enable/disable tooltips according to global gimprc settings
+ */
+gboolean
+gap_lib_check_tooltips(gboolean *old_state)
+{
+  char *value_string;
+  gboolean new_state;
+  gboolean changed;
+
+  new_state = TRUE;
+  changed = TRUE;
+  
+  value_string = gimp_gimprc_query("show-tooltips");
+  if(value_string != NULL)
+  {
+    if (strcmp(value_string, "no") == 0)
+    {
+       new_state = FALSE;
+    }
+  }
+  
+  if (old_state != NULL)
+  {
+    if(*old_state == new_state)
+    {
+      changed = FALSE;
+    }
+  }
+  
+  if (changed == TRUE)
+  {
+    if(new_state == TRUE)
+    {
+       gimp_help_enable_tooltips ();
+    }
+    else
+    {
+       gimp_help_disable_tooltips ();
+    }
+  }
+  
+  return (new_state);
+  
+}  /* end gap_lib_check_tooltips */
