@@ -46,8 +46,8 @@
 
 /* Defines */
 #define PLUG_IN_NAME        "plug_in_name2layer"
+#define PLUG_IN_HELP_ID     "plug-in-name2layer"
 #define PLUG_IN_PRINT_NAME  "Name to Layer"
-#define PLUG_IN_VERSION     "v2.0.2 (2004/05/06)"
 #define PLUG_IN_IMAGE_TYPES "RGB*, INDEXED*, GRAY*"
 #define PLUG_IN_AUTHOR      "Wolfgang Hofer (hof@gimp.org)"
 #define PLUG_IN_COPYRIGHT   "Wolfgang Hofer"
@@ -164,8 +164,8 @@ static void query (void)
                           "to the input drawable, otherwise a new textlayer is created",
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
-                          N_("<Image>/Video/Filename to Layer..."),
+                          GAP_VERSION_WITH_DATE,
+                          N_("Filename to Layer..."),
                           PLUG_IN_IMAGE_TYPES,
                           GIMP_PLUGIN,
                           global_number_in_args,
@@ -173,6 +173,8 @@ static void query (void)
                           in_args,
                           out_args);
 
+  // gimp_plugin_menu_branch_register("<Image>", "Video");
+  gimp_plugin_menu_register (PLUG_IN_NAME, N_("<Image>/Video/"));
 }  /* end query */
 
 static void
@@ -426,7 +428,7 @@ p_Naml (gint32 image_id, gint32 drawable_id)
 static gint
 Naml_dialog(void)
 {
-#define VR_NAME2LAYER_DIALOG_ARGC 8
+#define VR_NAME2LAYER_DIALOG_ARGC 9
 #define VR_MODELIST_SIZE 3
   static GapArrArg  argv[VR_NAME2LAYER_DIALOG_ARGC];
   gint ii;
@@ -451,7 +453,7 @@ Naml_dialog(void)
   ii++; gap_arr_arg_init(&argv[ii], GAP_ARR_WGT_FONTSEL);
   argv[ii].label_txt = _("Fontname:");
   argv[ii].entry_width = 350;       /* pixel */
-  argv[ii].help_txt  = _("Select Fontname)");
+  argv[ii].help_txt  = _("Select Fontname");
   argv[ii].text_buf_len = sizeof(glob_namlvals.fontname);
   argv[ii].text_buf_ret = &glob_namlvals.fontname[0];
   argv[ii].has_default = TRUE;
@@ -510,6 +512,9 @@ Naml_dialog(void)
   argv[ii].label_txt = _("Default");
   argv[ii].help_txt  = _("Reset all parameters to default values");
 
+  ii++; gap_arr_arg_init(&argv[ii], GAP_ARR_WGT_HELP_BUTTON);
+  argv[ii].help_id = PLUG_IN_HELP_ID;
+
   if(TRUE == gap_arr_ok_cancel_dialog(_("Render Filename to Layer"),
                             _("Settings :"),
                             VR_NAME2LAYER_DIALOG_ARGC, argv))
