@@ -495,6 +495,8 @@ gap_pview_render_from_buf (GapPView *pv_ptr
  * render preview widget from image.
  * IMPORTANT: the image is scaled to preview size
  *            and the visible layers in the image are merged together !
+ *            If the supplied image shall stay unchanged,
+ *            you may use  gap_pview_render_from_image_duplicate
  *
  * hint: call gtk_widget_queue_draw(pv_ptr->da_widget);
  * after this procedure to make the changes appear on screen.
@@ -506,7 +508,7 @@ gap_pview_render_from_image (GapPView *pv_ptr, gint32 image_id)
   guchar *frame_data;
   GimpPixelRgn pixel_rgn;
   GimpDrawable *drawable;
-  
+
   if(image_id < 0)
   {
     if(gap_debug)
@@ -518,7 +520,11 @@ gap_pview_render_from_image (GapPView *pv_ptr, gint32 image_id)
     return;
   }
 
-  gimp_image_scale(image_id, pv_ptr->pv_width, pv_ptr->pv_height);
+  if((gimp_image_width(image_id) != pv_ptr->pv_width)
+  || ( gimp_image_height(image_id) != pv_ptr->pv_height))
+  {
+    gimp_image_scale(image_id, pv_ptr->pv_width, pv_ptr->pv_height);
+  }
 
   /* workaround: gimp_image_merge_visible_layers
    * needs at least 2 layers to work without complaining
@@ -546,6 +552,7 @@ gap_pview_render_from_image (GapPView *pv_ptr, gint32 image_id)
                                 , 0         /* NORMAL */
                                 );   
     gimp_image_add_layer(image_id, l_layer_id, 0);
+    gimp_layer_resize_to_image_size(l_layer_id);
   }
   
     
@@ -568,6 +575,7 @@ gap_pview_render_from_image (GapPView *pv_ptr, gint32 image_id)
  
  {
     gboolean frame_data_was_grabbed;
+
     frame_data_was_grabbed = gap_pview_render_from_buf (pv_ptr
                    , frame_data
                    , drawable->width
@@ -581,6 +589,31 @@ gap_pview_render_from_image (GapPView *pv_ptr, gint32 image_id)
   
 }  /* end gap_pview_render_from_image */
 
+/* -------------------------------------
+ * gap_pview_render_from_image_duplicate
+ * -------------------------------------
+ * render preview widget from image.
+ * This procedure creates a temorary copy of the image
+ * for rendering of the preview.
+ * NOTE: if the caller wants to render a temporary image
+ *       that is not needed anymore after the rendering,
+ *       the procedure gap_pview_render_from_image should be used
+ *       to avoid duplicating of the image.
+ *
+ * hint: call gtk_widget_queue_draw(pv_ptr->da_widget);
+ * after this procedure to make the changes appear on screen.
+ */
+void
+gap_pview_render_from_image_duplicate (GapPView *pv_ptr, gint32 image_id)
+{
+  gint32 dup_image_id;
+  
+  dup_image_id = gimp_image_duplicate(image_id);
+  gimp_image_undo_disable (dup_image_id); 
+  gap_pview_render_from_image(pv_ptr, dup_image_id);
+  gimp_image_delete(dup_image_id);
+  
+}  /* end gap_pview_render_from_image_duplicate */
 
 /* ------------------------------
  * gap_pview_render_default_icon
@@ -861,3 +894,187 @@ gap_pview_render_from_pixbuf (GapPView *pv_ptr, GdkPixbuf *src_pixbuf)
 
 #endif
 
+
+
+/* ------------------------------
+ * p_pixmap_data_destructor
+ * ------------------------------
+ * a wrapper to g_free
+ * just for printing debug output at testing
+ */
+static void
+p_pixmap_data_destructor(gpointer data)
+{
+  if(gap_debug)
+  {
+    printf(" -- DESTRUCTOR p_pixmap_data_destructor called\n");
+    printf(" -- data: %d\n", (int)data);
+  }
+  g_free(data);
+  
+}
+
+
+/* ------------------------------
+ * gap_pview_get_repaint_pixbuf
+ * ------------------------------
+ * return the repaint buffer as GdkPixbuf,
+ * or NULL if no buffer is available.
+ */
+GdkPixbuf *
+gap_pview_get_repaint_pixbuf(GapPView   *pv_ptr)
+{ 
+  int bits_per_sample;
+  int rowstride;
+  int width;
+  int height;
+  gboolean has_alpha;
+  guchar *pixel_data_src;
+  guchar *pixel_data_copy;
+  
+  
+  if (pv_ptr == NULL)
+  {
+    return(NULL);
+  }
+
+  bits_per_sample = 8;
+  rowstride = pv_ptr->pv_width * pv_ptr->pv_bpp;
+  has_alpha = FALSE;
+  width = pv_ptr->pv_width;
+  height = pv_ptr->pv_height;
+  pixel_data_src = NULL;
+  
+  if ((pv_ptr->use_pixbuf_repaint) 
+  && (pv_ptr->pixbuf))
+  {
+    pixel_data_src = gdk_pixbuf_get_pixels(pv_ptr->pixbuf);
+    rowstride = gdk_pixbuf_get_rowstride(pv_ptr->pixbuf);
+    bits_per_sample = gdk_pixbuf_get_bits_per_sample(pv_ptr->pixbuf);
+    has_alpha = gdk_pixbuf_get_has_alpha(pv_ptr->pixbuf);
+  }
+  
+  if ((pv_ptr->use_pixmap_repaint) 
+  && (pv_ptr->pixmap)
+  && (pixel_data_src == NULL))
+  { 
+    gdk_drawable_get_size (pv_ptr->pixmap, &width, &height);
+    // pixel_data_src = ???; 
+    // TODO: how to make duplicate of pixeldata for GdkPixmap ?
+    // not critical, the pixmap is currently used only for the default icon
+    // that is renderd in case no useful pixeldata is available.
+    // The caller has to deal with returned NULL pointer anyway.
+ 
+    return(NULL);
+  }
+
+  if((pv_ptr->pv_area_data)
+  && (pixel_data_src == NULL))
+  {
+    pixel_data_src = pv_ptr->pv_area_data;
+  }
+
+  if(pixel_data_src)
+  {
+    size_t pixel_data_size = pv_ptr->pv_height * pv_ptr->pv_width * pv_ptr->pv_bpp;
+    pixel_data_copy = g_new ( guchar, pixel_data_size );
+    memcpy(pixel_data_copy, pixel_data_src, pixel_data_size);			    
+
+    return(gdk_pixbuf_new_from_data(
+            pixel_data_copy
+            , GDK_COLORSPACE_RGB
+            , has_alpha
+            , bits_per_sample
+            , width
+            , height
+            , rowstride
+            , p_pixmap_data_destructor  /* GdkPixbufDestroyNotify destroy_fn */
+            , pixel_data_copy    /* gpointer destroy_fn_data */
+	));
+  }
+  return (NULL);
+}  /* end gap_pview_get_repaint_pixbuf */
+
+
+/* ------------------------------
+ * gap_pview_get_repaint_thdata
+ * ------------------------------
+ * return the repaint buffer as thumbnail data (guchar RGB),
+ * or NULL if no buffer is available.
+ */
+guchar *
+gap_pview_get_repaint_thdata(GapPView   *pv_ptr        /* IN */
+                            , gint32    *th_size       /* OUT */
+                            , gint32    *th_width      /* OUT */
+                            , gint32    *th_height     /* OUT */
+                            , gint32    *th_bpp        /* OUT */
+                            , gboolean  *th_has_alpha  /* OUT */
+                            )
+{ 
+  int bits_per_sample;
+  int rowstride;
+  int width;
+  int height;
+  gboolean has_alpha;
+  guchar *pixel_data_src;
+  guchar *pixel_data_copy;
+  
+  
+  if (pv_ptr == NULL)
+  {
+    return(NULL);
+  }
+
+  bits_per_sample = 8;
+  rowstride = pv_ptr->pv_width * pv_ptr->pv_bpp;
+  has_alpha = FALSE;
+  width = pv_ptr->pv_width;
+  height = pv_ptr->pv_height;
+  pixel_data_src = NULL;
+  
+  if ((pv_ptr->use_pixbuf_repaint) 
+  && (pv_ptr->pixbuf))
+  {
+    pixel_data_src = gdk_pixbuf_get_pixels(pv_ptr->pixbuf);
+    rowstride = gdk_pixbuf_get_rowstride(pv_ptr->pixbuf);
+    bits_per_sample = gdk_pixbuf_get_bits_per_sample(pv_ptr->pixbuf);
+    has_alpha = gdk_pixbuf_get_has_alpha(pv_ptr->pixbuf);
+  }
+  
+  if ((pv_ptr->use_pixmap_repaint) 
+  && (pv_ptr->pixmap)
+  && (pixel_data_src == NULL))
+  { 
+    gdk_drawable_get_size (pv_ptr->pixmap, &width, &height);
+    // pixel_data_src = ???; 
+    // TODO: how to make duplicate of pixeldata for GdkPixmap ?
+    // not critical, the pixmap is currently used only for the default icon
+    // that is renderd in case no useful pixeldata is available.
+    // The caller has to deal with returned NULL pointer anyway.
+ 
+    return(NULL);
+  }
+
+  if((pv_ptr->pv_area_data)
+  && (pixel_data_src == NULL))
+  {
+    pixel_data_src = pv_ptr->pv_area_data;
+  }
+
+  if(pixel_data_src)
+  {
+    size_t pixel_data_size = pv_ptr->pv_height * pv_ptr->pv_width * pv_ptr->pv_bpp;
+    pixel_data_copy = g_new ( guchar, pixel_data_size );
+    memcpy(pixel_data_copy, pixel_data_src, pixel_data_size);			    
+
+    *th_size       = width * height * pv_ptr->pv_bpp;
+    *th_width      = width;
+    *th_height     = height;
+    *th_bpp        = pv_ptr->pv_bpp;
+    *th_has_alpha  = has_alpha;
+
+    return (pixel_data_copy);
+  }
+  return (NULL);
+
+} /* end gap_pview_get_repaint_thdata */
