@@ -49,10 +49,11 @@
 
 #include "config.h"
 
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include <glib/gstdio.h>
+
 #include <gtk/gtk.h>
 
 #include <libgimp/gimp.h>
@@ -64,16 +65,15 @@
 
 
 /* Defines */
-#define PLUG_IN_NAME        "plug_in_wr_curves"
-#define PLUG_IN_VERSION     "v1.3 (2003/12/19)"
+#define PLUG_IN_NAME        "plug-in-wr-curves"
 #define PLUG_IN_IMAGE_TYPES "RGB*, GRAY*"
 #define PLUG_IN_AUTHOR      "Wolfgang Hofer (hof@gimp.org)"
 #define PLUG_IN_COPYRIGHT   "Wolfgang Hofer"
 #define PLUG_IN_DESCRIPTION "Wrapper for GIMP Curves Tool call based on Curves file"
 
-#define PLUG_IN_ITER_NAME       "plug_in_wr_curves_Iterator"
-#define PLUG_IN_DATA_ITER_FROM  "plug_in_wr_curves_ITER_FROM"
-#define PLUG_IN_DATA_ITER_TO    "plug_in_wr_curves_ITER_TO"
+#define PLUG_IN_ITER_NAME       "plug-in-wr-curves-Iterator"
+#define PLUG_IN_DATA_ITER_FROM  "plug-in-wr-curves-ITER-FROM"
+#define PLUG_IN_DATA_ITER_TO    "plug-in-wr-curves-ITER-TO"
 
 #define PLUG_IN_HELP_ID         "plug-in-wr-curves"
 
@@ -389,7 +389,7 @@ p_load_curve(gchar *filename, wr_curves_val_t *cuvals)
 {
   FILE  *fp;
 
-  fp = fopen (filename, "rt");
+  fp = g_fopen (filename, "rt");
 
   if (!fp)
   {
@@ -512,6 +512,8 @@ query (void)
   static GimpParamDef *return_iter = NULL;
   static int nreturn_iter = 0;
 
+  gimp_plugin_domain_register (GETTEXT_PACKAGE, LOCALEDIR);
+
   /* the actual installation of the bend plugin */
   gimp_install_procedure (PLUG_IN_NAME,
                           PLUG_IN_DESCRIPTION,
@@ -525,8 +527,8 @@ query (void)
                           ,
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
-                          N_("<Image>/Video/Layer/Colors/CurvesFile..."),
+                          GAP_VERSION_WITH_DATE,
+                          N_("CurvesFile..."),
                           PLUG_IN_IMAGE_TYPES,
                           GIMP_PLUGIN,
                           nargs,
@@ -541,12 +543,22 @@ query (void)
                           "",
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
+                          GAP_VERSION_WITH_DATE,
                           NULL,    /* do not appear in menus */
                           NULL,
                           GIMP_PLUGIN,
                           nargs_iter, nreturn_iter,
                           args_iter, return_iter);
+  {
+    /* Menu names */
+    const char *menupath_image_video_layer_colors = N_("<Image>/Video/Layer/Colors/");
+
+    //gimp_plugin_menu_branch_register("<Image>", "Video");
+    //gimp_plugin_menu_branch_register("<Image>/Video", "Layer");
+    //gimp_plugin_menu_branch_register("<Image>/Video/Layer", "Colors");
+
+    gimp_plugin_menu_register (PLUG_IN_NAME, menupath_image_video_layer_colors);
+  }
 }
 
 
@@ -665,7 +677,7 @@ run(const gchar *name
 
       case GIMP_RUN_NONINTERACTIVE:
         /* check to see if invoked with the correct number of parameters */
-        if (nparams >= 5)
+        if (nparams >= 4)
         {
            wcd = g_malloc (sizeof (WrCurveDialog));
            wcd->run = TRUE;
