@@ -1,4 +1,4 @@
-/* wr_color_hue_saturation.c
+/* gap_wr_color_hue_saturation.c
  * 2002.Jan.01 hof (Wolfgang Hofer)
  *
  *  Wrapper Plugin for GIMP Hue Saturation tool
@@ -54,15 +54,15 @@
 #include "gap-intl.h"
 
 /* Defines */
-#define PLUG_IN_NAME        "plug_in_wr_huesat"
+#define PLUG_IN_NAME        "plug-in-wr-huesat"
 #define PLUG_IN_IMAGE_TYPES "RGB*, GRAY*"
 #define PLUG_IN_AUTHOR      "Wolfgang Hofer (hof@gimp.org)"
 #define PLUG_IN_COPYRIGHT   "Wolfgang Hofer"
 #define PLUG_IN_DESCRIPTION "Wrapper call for GIMP Hue Saturation Color Tool"
 
-#define PLUG_IN_ITER_NAME       "plug_in_wr_huesat_Iterator"
-#define PLUG_IN_DATA_ITER_FROM  "plug_in_wr_huesat_ITER_FROM"
-#define PLUG_IN_DATA_ITER_TO    "plug_in_wr_huesat_ITER_TO"
+#define PLUG_IN_ITER_NAME       "plug-in-wr-huesat-Iterator"
+#define PLUG_IN_DATA_ITER_FROM  "plug-in-wr-huesat-ITER-FROM"
+#define PLUG_IN_DATA_ITER_TO    "plug-in-wr-huesat-ITER-TO"
 #define PLUG_IN_HELP_ID         "plug-in-wr-huesat"
 
 
@@ -246,6 +246,8 @@ query (void)
   static GimpParamDef *return_iter = NULL;
   static int nreturn_iter = 0;
 
+  gimp_plugin_domain_register (GETTEXT_PACKAGE, LOCALEDIR);
+
   /* the actual installation of the bend plugin */
   gimp_install_procedure (PLUG_IN_NAME,
                           PLUG_IN_DESCRIPTION,
